@@ -10,7 +10,7 @@ import pandas as pd
 import xarray as xr
 from openpyxl import load_workbook
 
-from .ws.settings import NotLevels
+from .ws.settings import ws_settings
 
 try:
     from StringIO import StringIO as BytesIO
@@ -967,13 +967,15 @@ class PyplanFunctions(object):
                 return values[selection-1]
         return ""
 
-    def dynamic(self, dataArray, index, shift, initialValues=None):
+    def dynamic(self, dataArray, index, shift, initialValues=None, sliceInputs=False):
         """Performs cyclic calculations between nodes.
 
            dataArray: dataArray to perform the ciclyc dependency calculation
            index: Index from dataArray to shift 
            shift: number of elemnts to shift. Can be positive or negative
            initialValues (optional): scalar or 1-dim dataArray. Initial values to apply to first "shift" elements
+           sliceInputs (optional): boolean to apply subscript to every input in dynamic loop. If one of the nodes
+            in dynamic loop is set to True, it applies it to every other node in the loop
         """
 
         _da = dataArray.shift({index.name: (shift*-1)})
@@ -1174,12 +1176,9 @@ class PyplanFunctions(object):
         """
 
         if self.model and self.model.ws:
-            notification_levels = [
-                NotLevels.INFO, NotLevels.SUCCESS, NotLevels.WARNING, NotLevels.ERROR]
-            not_level_reverse = NotLevels(not_level_reverse) if NotLevels(
-                not_level_reverse) in notification_levels else NotLevels.INFO
-            self.model.ws.ws_notification_message(
-                message=message_text, title=message_title, not_level=not_level_reverse)
+            not_level = ws_settings.NOTIFICATION_LEVEL_CHOICES_REVERSE[
+                not_level_reverse] if not_level_reverse in ws_settings.NOTIFICATION_LEVEL_CHOICES_REVERSE else ws_settings.NOTIFICATION_LEVEL_INFO
+            self.model.ws.sendMsg(message_text, message_title, not_level)
 
     def progressbar(self, progress, message_text="", not_level_reverse="info"):
         """Creates and updates progress bar. Only used with Pyplan UI
@@ -1189,12 +1188,9 @@ class PyplanFunctions(object):
         """
 
         if self.model and self.model.ws:
-            notification_levels = [
-                NotLevels.INFO, NotLevels.SUCCESS, NotLevels.WARNING, NotLevels.ERROR]
-            not_level_reverse = NotLevels(not_level_reverse) if NotLevels(
-                not_level_reverse) in notification_levels else NotLevels.INFO
-            self.model.ws.ws_notification_progress_bar(
-                progress=progress, message=message_text, not_level=not_level_reverse)
+            not_level = ws_settings.NOTIFICATION_LEVEL_CHOICES_REVERSE[
+                not_level_reverse] if not_level_reverse in ws_settings.NOTIFICATION_LEVEL_CHOICES_REVERSE else ws_settings.NOTIFICATION_LEVEL_INFO
+            self.model.ws.progressbar(progress, message_text, not_level)
 
     def create_report(self, reportItems, reportIndexName="Report index", reportIndex=None):
         """Concatenates the reportItems dic dataArrays along the reportIndex dimension
